#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hindent
version:              6.2.0
visibility:           public
id:                   hindent-6.2.0-5mYJee84DO27XuZ87FK1AQ
key:                  hindent-6.2.0-5mYJee84DO27XuZ87FK1AQ
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    See the GitHub page for usage \/ explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  369f9ba7e09858d3c575780f8c9ceeaf
exposed:              True
exposed-modules:      HIndent
hidden-modules:
    HIndent.Applicative HIndent.Ast HIndent.Ast.Context
    HIndent.Ast.Declaration HIndent.Ast.Declaration.Annotation
    HIndent.Ast.Declaration.Annotation.Provenance
    HIndent.Ast.Declaration.Annotation.Role
    HIndent.Ast.Declaration.Bind HIndent.Ast.Declaration.Class
    HIndent.Ast.Declaration.Class.FunctionalDependency
    HIndent.Ast.Declaration.Class.NameAndTypeVariables
    HIndent.Ast.Declaration.Collection HIndent.Ast.Declaration.Data
    HIndent.Ast.Declaration.Data.Body
    HIndent.Ast.Declaration.Data.Deriving
    HIndent.Ast.Declaration.Data.Deriving.Clause
    HIndent.Ast.Declaration.Data.Deriving.Strategy
    HIndent.Ast.Declaration.Data.GADT.Constructor
    HIndent.Ast.Declaration.Data.GADT.Constructor.Signature
    HIndent.Ast.Declaration.Data.Haskell98.Constructor
    HIndent.Ast.Declaration.Data.Haskell98.Constructor.Body
    HIndent.Ast.Declaration.Data.Header
    HIndent.Ast.Declaration.Data.NewOrData
    HIndent.Ast.Declaration.Data.Record.Field
    HIndent.Ast.Declaration.Default HIndent.Ast.Declaration.Family.Data
    HIndent.Ast.Declaration.Family.Type
    HIndent.Ast.Declaration.Family.Type.Injectivity
    HIndent.Ast.Declaration.Family.Type.ResultSignature
    HIndent.Ast.Declaration.Foreign
    HIndent.Ast.Declaration.Foreign.CallingConvention
    HIndent.Ast.Declaration.Foreign.Safety
    HIndent.Ast.Declaration.Instance.Class
    HIndent.Ast.Declaration.Instance.Class.OverlapMode
    HIndent.Ast.Declaration.Instance.Family.Data
    HIndent.Ast.Declaration.Instance.Family.Type
    HIndent.Ast.Declaration.Rule HIndent.Ast.Declaration.Rule.Binder
    HIndent.Ast.Declaration.Rule.Collection
    HIndent.Ast.Declaration.Signature
    HIndent.Ast.Declaration.Signature.BooleanFormula
    HIndent.Ast.Declaration.Signature.Fixity
    HIndent.Ast.Declaration.Signature.Fixity.Associativity
    HIndent.Ast.Declaration.Signature.Inline.Phase
    HIndent.Ast.Declaration.Signature.Inline.Spec
    HIndent.Ast.Declaration.Signature.StandaloneKind
    HIndent.Ast.Declaration.Splice
    HIndent.Ast.Declaration.StandAloneDeriving
    HIndent.Ast.Declaration.TypeSynonym
    HIndent.Ast.Declaration.TypeSynonym.Lhs
    HIndent.Ast.Declaration.Warning
    HIndent.Ast.Declaration.Warning.Collection
    HIndent.Ast.Declaration.Warning.Kind HIndent.Ast.Expression.Bracket
    HIndent.Ast.Expression.Splice HIndent.Ast.FileHeaderPragma
    HIndent.Ast.FileHeaderPragma.Collection HIndent.Ast.Import
    HIndent.Ast.Import.Collection HIndent.Ast.Import.Entry
    HIndent.Ast.Import.Entry.Collection
    HIndent.Ast.Import.ImportingOrHiding HIndent.Ast.Module
    HIndent.Ast.Module.Declaration HIndent.Ast.Module.Export.Collection
    HIndent.Ast.Module.Export.Entry HIndent.Ast.Module.Name
    HIndent.Ast.Module.Warning HIndent.Ast.Name.Infix
    HIndent.Ast.Name.Prefix HIndent.Ast.NodeComments HIndent.Ast.Role
    HIndent.Ast.Type HIndent.Ast.Type.Variable HIndent.Ast.WithComments
    HIndent.ByteString HIndent.CabalFile HIndent.CodeBlock
    HIndent.CommandlineOptions HIndent.Config HIndent.Error
    HIndent.Fixity HIndent.GhcLibParserWrapper.GHC.Hs
    HIndent.GhcLibParserWrapper.GHC.Hs.ImpExp
    HIndent.GhcLibParserWrapper.GHC.Unit.Module.Warnings
    HIndent.Language HIndent.LanguageExtension
    HIndent.LanguageExtension.Conversion
    HIndent.LanguageExtension.Types HIndent.ModulePreprocessing
    HIndent.ModulePreprocessing.CommentRelocation HIndent.Parse
    HIndent.Path.Find HIndent.Pragma HIndent.Pretty
    HIndent.Pretty.Combinators HIndent.Pretty.Combinators.Comment
    HIndent.Pretty.Combinators.Getter HIndent.Pretty.Combinators.Indent
    HIndent.Pretty.Combinators.Lineup HIndent.Pretty.Combinators.Op
    HIndent.Pretty.Combinators.Outputable
    HIndent.Pretty.Combinators.RhsSeparator
    HIndent.Pretty.Combinators.String HIndent.Pretty.Combinators.Switch
    HIndent.Pretty.Combinators.Wrap HIndent.Pretty.NodeComments
    HIndent.Pretty.SigBindFamily HIndent.Pretty.Types HIndent.Printer
    Paths_hindent

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hindent-6.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hindent-6.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hindent-6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-6.2.0-5mYJee84DO27XuZ87FK1AQ
depends:
    Cabal-3.10.3.0 async-2.2.6-BOzBj9OU2RsBdXVaxuDTSw base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-lib-parser-ex-9.6.0.2-5nEc42ERGoN3S0Hw71n3ZC
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    optparse-applicative-0.18.1.0-8Us6opzobWeE8qMBykWiRI
    path-0.9.6-GztXZKf17iiBydBxqKmqaR
    path-io-1.8.2-4BGDxXhcnF7GZy9alBMQfx
    regex-tdfa-1.3.2.6-7s6a3kMa1YssqXiRAnHSe
    split-0.2.5.1-FQ4kT9wgw7JDP8h2QeY4XG
    syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE transformers-0.6.1.0
    unicode-show-0.1.1.1-9E0PeCusXWMD4uOR5bqXLP
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    yaml-0.11.11.2-7C8te7oEKag5lil8hT24q7

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-hindent-z-hindent-internal
version:              6.2.0
package-name:         hindent
lib-name:             hindent-internal
id:                   hindent-6.2.0-1B3Axyv99SRDPTqDtFdkm9-hindent-internal
key:                  hindent-6.2.0-1B3Axyv99SRDPTqDtFdkm9-hindent-internal
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    See the GitHub page for usage \/ explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  aba73f3cf002d9e98b8543d0b303cc66
exposed-modules:      HIndent.Internal.Test.Markdone
hidden-modules:       Paths_hindent
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hindent-6.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hindent-6.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hindent-6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-6.2.0-1B3Axyv99SRDPTqDtFdkm9-hindent-internal
depends:
    Cabal-3.10.3.0 async-2.2.6-BOzBj9OU2RsBdXVaxuDTSw base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1 ghc-9.6.6
    ghc-boot-9.6.6 ghc-lib-parser-ex-9.6.0.2-5nEc42ERGoN3S0Hw71n3ZC
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    optparse-applicative-0.18.1.0-8Us6opzobWeE8qMBykWiRI
    path-0.9.6-GztXZKf17iiBydBxqKmqaR
    path-io-1.8.2-4BGDxXhcnF7GZy9alBMQfx
    regex-tdfa-1.3.2.6-7s6a3kMa1YssqXiRAnHSe
    split-0.2.5.1-FQ4kT9wgw7JDP8h2QeY4XG
    syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE transformers-0.6.1.0
    unicode-show-0.1.1.1-9E0PeCusXWMD4uOR5bqXLP
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    yaml-0.11.11.2-7C8te7oEKag5lil8hT24q7

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

